pub enum PathValidationError {
Show 17 variants
AlpmCommon(Error),
CreateHashDigest {
path: PathBuf,
source: Error,
},
PathDigestMismatch {
mtree_path: PathBuf,
mtree_digest: Sha256Checksum,
path: PathBuf,
path_digest: Sha256Checksum,
},
PathGidMismatch {
mtree_path: PathBuf,
mtree_gid: u32,
path: PathBuf,
path_gid: u32,
},
PathMetadata {
path: PathBuf,
source: Error,
},
PathMismatch {
mtree_path: PathBuf,
path: PathBuf,
},
PathMissing {
mtree_path: PathBuf,
path: PathBuf,
},
PathModeMismatch {
mtree_path: PathBuf,
mtree_mode: String,
path: PathBuf,
path_mode: String,
},
PathNotADir {
mtree_path: PathBuf,
path: PathBuf,
},
PathNotAFile {
mtree_path: PathBuf,
path: PathBuf,
},
PathSizeMismatch {
mtree_path: PathBuf,
mtree_size: u64,
path: PathBuf,
path_size: u64,
},
PathSymlinkMismatch {
mtree_path: PathBuf,
mtree_link_path: PathBuf,
path: PathBuf,
link_path: PathBuf,
},
PathTimeMismatch {
mtree_path: PathBuf,
mtree_time: i64,
path: PathBuf,
path_time: i64,
},
PathUidMismatch {
mtree_path: PathBuf,
mtree_uid: u32,
path: PathBuf,
path_uid: u32,
},
ReadLink {
path: PathBuf,
mtree_path: PathBuf,
source: Error,
},
UnmatchedFileSystemPaths {
paths: Vec<PathBuf>,
},
UnmatchedMtreePaths {
paths: Vec<PathBuf>,
},
}Expand description
The error that can occur when comparing Mtree paths with paths on a file system.
Variants
AlpmCommon(Error)
Alpm-common error.
CreateHashDigest
Unable to create hash digest for a path.
Fields
PathDigestMismatch
The hash digest of a path in the ALPM-MTREE data does not match that of the corresponding on-disk file.
Fields
mtree_digest: Sha256ChecksumThe size of the path according to ALPM-MTREE data.
path_digest: Sha256ChecksumThe on-disk path, that does not match the size of the ALPM-MTREE data.
PathGidMismatch
The GID of a path in the ALPM-MTREE metadata does not match that of the corresponding on-disk file.
Fields
PathMetadata
The metadata for a path can not be retrieved.
Fields
PathMismatch
A path does not match what it is supposed to be.
Fields
PathMissing
An on-disk path does not exist.
Fields
PathModeMismatch
The mode of a path in the ALPM-MTREE metadata does not match that of the corresponding on-disk file.
Fields
PathNotADir
An on-disk path is not a directory.
Fields
PathNotAFile
An on-disk path is not a file.
Fields
PathSizeMismatch
The size of a path in the ALPM-MTREE metadata does not match the size of the corresponding on-disk file.
Fields
PathSymlinkMismatch
A path does not match what it is supposed to be.
Fields
PathTimeMismatch
The time of a path in the ALPM-MTREE metadata does not match the time of the corresponding on-disk file.
Fields
PathUidMismatch
The UID of a path in the ALPM-MTREE metadata does not match that of the corresponding on-disk file.
Fields
ReadLink
Unable to read a link.
Fields
UnmatchedFileSystemPaths
There are file system paths for which no matching ALPM-MTREE paths exist.
Fields
UnmatchedMtreePaths
There are ALPM-MTREE paths for which no matching file system paths exist.